@@ -20,15 +20,13 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include <config.h>
+#include "nm-default.h"
 
 #include <net/ethernet.h>
 #include <netinet/ether.h>
 #include <string.h>
 #include <stdlib.h>
 
-#include <glib/gi18n.h>
-
 #include "ce-page.h"
 
 G_DEFINE_ABSTRACT_TYPE (CEPage, ce_page, G_TYPE_OBJECT)
