@@ -17,14 +17,12 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2012 Red Hat, Inc.
+ * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
 #ifndef __PAGE_MOBILE_H__
 #define __PAGE_MOBILE_H__
 
-#include <nm-connection.h>
-
 #include <glib.h>
 #include <glib-object.h>
 
@@ -51,13 +49,12 @@ CEPage *ce_page_mobile_new (NMConnectionEditor *editor,
                             NMConnection *connection,
                             GtkWindow *parent,
                             NMClient *client,
-                            NMRemoteSettings *settings,
                             const char **out_secrets_setting_name,
                             GError **error);
 
 void mobile_connection_new (GtkWindow *parent,
                             const char *detail,
-                            NMRemoteSettings *settings,
+                            NMClient *client,
                             PageNewConnectionResultFunc result_func,
                             gpointer user_data);
 
