@@ -22,14 +22,12 @@
  * Copyright (C) 2012 Lanedo GmbH
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 #include <errno.h>
 #include <stdlib.h>
 
-#include <glib/gi18n-lib.h>
-
 #include "nma-mobile-providers.h"
 
 #ifndef MOBILE_BROADBAND_PROVIDER_INFO
